.. image:: https://travis-ci.org/csiro-aquatic-remote-sensing/sambuca_core.svg
    :target: https://travis-ci.org/csiro-aquatic-remote-sensing/sambuca_core
    :alt: Build Status

.. image:: https://readthedocs.org/projects/sambuca-core/badge/?version=latest
    :target: https://sambuca-core.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

* **Free software:** CSIRO Open Source Software Licence Agreement
* **Homepage:** https://github.com/csiro-aquatic-remote-sensing/sambuca_core
* **Documentation:** https://sambuca-core.readthedocs.io/en/latest/
* **Version:** 1.3.3

Contains the core model components for the Semi-Analytical Model
for Bathymetry, Un-mixing, and Concentration Assessment (SAMBUCA).

Installation
------------
::

    pip install sambuca_core

For everything else, please refer to the
`project documentation <https://sambuca-core.readthedocs.io/en/latest/>`_.
